@@ -15,6 +15,7 @@ import pypistats
 from .data.expected_tabulated import (
     EXPECTED_TABULATED_HTML,
     EXPECTED_TABULATED_MD,
+    EXPECTED_TABULATED_PRETTY,
     EXPECTED_TABULATED_RST,
     EXPECTED_TABULATED_TSV,
 )
@@ -215,7 +216,7 @@ class TestPypiStats:
         # Act / Assert
         assert pypistats._can_do_colour() is True
 
-    def test__colourify(self) -> None:
+    def test__colourify(self, monkeypatch) -> None:
         # Arrange
         data = [
             {"category": "2.7", "downloads": 1},
@@ -233,6 +234,7 @@ class TestPypiStats:
         ]
         data = pypistats._percent(data)
         data = pypistats._grand_total(data)
+        monkeypatch.setenv("FORCE_COLOR", "1")
 
         # Act
         output = pypistats._colourify(data)
@@ -256,6 +258,7 @@ class TestPypiStats:
         [
             pytest.param("html", EXPECTED_TABULATED_HTML, id="html"),
             pytest.param("markdown", EXPECTED_TABULATED_MD, id="markdown"),
+            pytest.param("pretty", EXPECTED_TABULATED_PRETTY, id="pretty"),
             pytest.param("rst", EXPECTED_TABULATED_RST, id="rst"),
             pytest.param("tsv", EXPECTED_TABULATED_TSV, id="tsv"),
         ],
@@ -265,7 +268,7 @@ class TestPypiStats:
         data = copy.deepcopy(SAMPLE_DATA)
 
         # Act
-        output = pypistats._tabulate(data, format=test_input)
+        output = pypistats._tabulate(data, format_=test_input)
 
         # Assert
         assert output.strip() == expected.strip()
@@ -521,7 +524,9 @@ Date range: 2020-05-02 - 2020-05-02
 
         # Act
         respx.get(mocked_url).respond(content=mocked_response)
-        output = pypistats.overall(package, mirrors=False, start_date="2020-05-02")
+        output = pypistats.overall(
+            package, mirrors=False, start_date="2020-05-02", format="md"
+        )
 
         # Assert
         assert output.strip() == expected_output.strip()
@@ -544,7 +549,9 @@ Date range: 2020-05-01 - 2020-05-01
 
         # Act
         respx.get(mocked_url).respond(content=mocked_response)
-        output = pypistats.overall(package, mirrors=False, end_date="2020-05-01")
+        output = pypistats.overall(
+            package, mirrors=False, end_date="2020-05-01", format="md"
+        )
 
         # Assert
         assert output.strip() == expected_output.strip()
@@ -654,7 +661,7 @@ Date range: 2020-05-01 - 2020-05-01
 
         # Act
         respx.get(mocked_url).respond(content=mocked_response)
-        output = pypistats.system(package)
+        output = pypistats.system(package, format="md")
 
         # Assert
         assert output.strip() == expected_output.strip()
@@ -708,7 +715,7 @@ Date range: 2020-05-01 - 2020-05-01
 """
 
         # Act
-        output = pypistats._tabulate(data, format="markdown")
+        output = pypistats._tabulate(data, format_="markdown")
 
         # Assert
         assert output.strip() == expected_output.strip()
